@@ -1,18 +1,25 @@
 import os
+from typing import List, cast
 
 from portmod.loader import load_all
-from portmodlib.masters import get_masters
+from portmodlib.execute import execute
 
 from .datadir import find_esp_bsa
 
 
+def get_masters(plugin: str) -> List[str]:
+    return cast(
+        str, execute(f'delta_plugin deps "{plugin}"', pipe_output=True)
+    ).splitlines()
+
+
 class DependencyException(Exception):
     pass
 
 
 # Detect masters using tes3cmd and determine which atom they correspond to
 def get_esp_deps(file, datadirs, atom):
-    masters = get_masters(file)
+    masters = set(get_masters(file))
 
     use = set()
     # Check if masters correspond to Tribunal.esm or Bloodmoon.esm, as they are pulled
