@@ -5,7 +5,7 @@ import re
 import shutil
 import urllib.parse
 from logging import error, warning
-from typing import Dict, List, Set
+from typing import Dict, List, Optional, Set
 
 import black
 import git
@@ -26,12 +26,11 @@ from portmod.util import get_newest
 from portmodlib.atom import Atom, version_gt
 from portmodlib.colour import colour
 from portmodlib.fs import get_hash
-from portmodlib.masters import get_masters
 from redbaron import AtomtrailersNode, CallNode, RedBaron
 
 from .atom import parse_atom
 from .datadir import find_data_dirs, find_esp_bsa, get_dominant_texture_size
-from .deps import DependencyException, get_esp_deps
+from .deps import DependencyException, get_esp_deps, get_masters
 from .sources.nexus import (
     APILimitExceeded,
     get_nexus_info,
@@ -153,6 +152,7 @@ def generate_build_files(
 
     sources: List[Source] = []
     source_string = url
+    nexus_source_string = None
 
     parsed = urllib.parse.urlparse(url)
     downloaded = False
@@ -215,12 +215,17 @@ def generate_build_files(
             url = None
             file = None
             downloaded = True
+            sources = []
             sources = [Source(file, file) for file in nexus_data.files]
-            source_string = " ".join([source.name for source in sources])
+            nexus_source_string = " ".join(
+                [
+                    f'https://nexusmods.com/{game}/mods/{mod_id}?tab=files&file_id={data["file_id"]} -> {name}'
+                    for name, data in nexus_data.files.items()
+                ]
+            )
             if nexus_data.nudity:
                 REQUIRED_USE.append("nudity")
             author = author or nexus_data.author
-            OTHER_FIELDS["NEXUS_URL"] = f'"{nexus_data.homepage}"'
             CLASS.append("NexusMod")
             if "common.nexus" not in OTHER_IMPORTS:
                 OTHER_IMPORTS["common.nexus"] = ["NexusMod"]
@@ -540,15 +545,27 @@ def generate_build_files(
             if not Mod.find("name", key):
                 Mod.append(f"{key}={values[key]}")
 
-        # Update SRC_URI unless there are no missing files
-        if Mod.find("name", "SRC_URI"):
-            old_value = Mod.find("name", "SRC_URI").parent.value
-            for file in source_string.split():
-                if file not in str(old_value):
-                    Mod.find("name", "SRC_URI").parent.value = f'"{source_string}"'
-                    break
+        if nexus_source_string:
+            if Mod.find("name", "NEXUS_SRC_URI"):
+                oldvalue = str(Mod.find("name", "NEXUS_SRC_URI").parent.value)
+                for source in sources:
+                    if source.name not in oldvalue:
+                        Mod.find(
+                            "name", "NEXUS_SRC_URI"
+                        ).parent.value = f'"{nexus_source_string}"'
+                        break
+            else:
+                Mod.append(f'NEXUS_SRC_URI="{nexus_source_string}"')
         else:
-            Mod.append(f'SRC_URI="{source_string}"')
+            # Update SRC_URI unless there are no missing files
+            if Mod.find("name", "SRC_URI"):
+                old_value = Mod.find("name", "SRC_URI").parent.value
+                for file in source_string.split():
+                    if file not in str(old_value):
+                        Mod.find("name", "SRC_URI").parent.value = f'"{source_string}"'
+                        break
+            else:
+                Mod.append(f'SRC_URI="{source_string}"')
 
         # Update S if present
         if Mod.find("name", "S") and len(sources) == 1:
@@ -562,7 +579,10 @@ def generate_build_files(
         )
         pybuild.append(f'class Package({", ".join(reversed(CLASS))}):\n   {valuestr}')
         Mod = pybuild.find("class", "Package")
-        Mod.append(f'SRC_URI="{source_string}"')
+        if nexus_source_string:
+            Mod.append(f'NEXUS_SRC_URI="{nexus_source_string}"')
+        else:
+            Mod.append(f'SRC_URI="{source_string}"')
 
     INSTALL_DIRS = sorted(INSTALL_DIRS, key=lambda x: (x.S, x.PATH))
     if Mod.find("name", "INSTALL_DIRS"):
@@ -616,7 +636,7 @@ def generate_build_files(
                 if new_dir.comment:
                     dirlist.node_list.append(RedBaron(new_dir.comment))
                     dirlist.node_list.append(RedBaron("\n"))
-                dirlist.node_list.append(RedBaron(str(new_dir) + ","))
+                dirlist.value.append(RedBaron(str(new_dir)))
 
     else:
         Mod.append(f'INSTALL_DIRS = [{", ".join(f"{d}" for d in INSTALL_DIRS)}]')
@@ -698,7 +718,21 @@ priority = 50
     print(colour(Fore.GREEN, "Finished Importing {}".format(atom)))
 
 
-def create_metadata(file, author):
+def create_metadata(
+    file: str,
+    author: Optional[str] = None,
+    longdescription: Optional[str] = None,
+    bugs_to: Optional[str] = None,
+    doc: Optional[str] = None,
+):
     with open(file, "w") as metadata:
+        if longdescription:
+            longdescription = longdescription.replace("'", "''")
+            print(f"longdescription: '{longdescription}'", file=metadata)
         print("upstream:", file=metadata)
-        print(f"    maintainer: {author}", file=metadata)
+        if author:
+            print(f"    maintainer: {author}", file=metadata)
+        if bugs_to:
+            print(f"    bugs-to: {bugs_to}", file=metadata)
+        if doc:
+            print(f"    doc: {doc}", file=metadata)
