@@ -17,7 +17,7 @@ class GithubSource(PackageSource):
         gh = Github()
         repo = gh.get_repo(self.id)
         releases = repo.get_releases()
-        if releases:
+        if releases and releases.totalCount > 0:
             return parse_version(releases[0].tag_name)
         else:
             return "0"
